// $URL: http://subversion:8080/svn/gsc/trunk/drivers/LINUX/24DSI6C500K/24DSI6C500K_1.x.x.x_GSC_DN/samples/fsamp/perform.c $
// $Rev: 52722 $
// $Date: 2023-04-03 14:00:34 -0500 (Mon, 03 Apr 2023) $

// 24DSI6C500K: Sample Application: source file

#include "main.h"



// macros *********************************************************************

#define	FILE_NAME				"fsamp.txt"
#define	LIMIT_MAX(v,max)		(((v) > (max)) ? (max) : (v))
#define	LIMIT_MIN(v,min)		(((v) < (min)) ? (min) : (v))
#define	LIMIT_RANGE(v,min,max)	(LIMIT_MIN((LIMIT_MAX((v),(max))),(min)))



//*****************************************************************************
int perform_tests(const args_t* args)
{
	int		errs		= 0;
	FILE*	file		= NULL;
	s32		fref;
	s32		fsamp;
	s32		max;
	s32		min;
	s32		ndiv;
	s32		nref;
	s32		nvco;
	s32		osr;
	double	rate;

	gsc_label("Fsamp Computation");
	printf("\n");
	gsc_label_level_inc();

	errs	+= dsi6c500k_query(args->fd, -1, 1, DSI6C500K_QUERY_FREF_DEFAULT, &fref);
	errs	+= dsi6c500k_query(args->fd, -1, 1, DSI6C500K_QUERY_FSAMP_MAX, &max);
	errs	+= dsi6c500k_query(args->fd, -1, 1, DSI6C500K_QUERY_FSAMP_MIN, &min);

	if (args->range == 0)
	{
		min	= LIMIT_RANGE(args->fsamp, min, max);
		max	= min;
	}

	if (args->save)
	{
		file	= fopen(FILE_NAME, "w+b");

		if (file == NULL)
		{
			printf("FAIL <---  (unable to create %s)\n", FILE_NAME);
			errs	= 1;
		}
		else
		{
			fprintf(file, "# 24DSI6C500K Scan Rates\n");
			fprintf(file, "# Request  Produced\n");
			fprintf(file, "# =======  ==========\n");
		}
	}

	for (fsamp = min; fsamp <= max; fsamp++)
	{
		errs	+= dsi6c500k_fsamp_ai_compute(args->fd, -1, 1, fref, fsamp, &nvco, &nref, &ndiv, &osr, &rate);

		if (file)
		{
			switch (osr)
			{
				default:
				case DSI6C500K_OSR_32:	osr	= 32;	break;
				case DSI6C500K_OSR_64:	osr	= 64;	break;
				case DSI6C500K_OSR_128:	osr	= 128;	break;
				case DSI6C500K_OSR_256:	osr	= 256;	break;
			}

			rate	= ((double) fref * nvco) / (nref * 2 * osr * ndiv);
			fprintf(file, "%9ld  %10.3f\n", (long) fsamp, rate);
		}
	}

	if (file)
		fclose(file);

	gsc_label_level_dec();
	return(errs);
}


