// $URL: http://subversion:8080/svn/gsc/trunk/drivers/LINUX/24DSI6C500K/24DSI6C500K_1.x.x.x_GSC_DN/utils/util_auto_cal_sts.c $
// $Rev: 46781 $
// $Date: 2020-01-09 17:04:13 -0600 (Thu, 09 Jan 2020) $

// 24DSI6C500K: Utilities: source file

#include "main.h"



/******************************************************************************
*
*	Function:	dsi6c500k_auto_cal_sts
*
*	Purpose:
*
*		Provide a visual wrapper for the DSI6C500K_IOCTL_AUTO_CAL_STS service.
*
*	Arguments:
*
*		fd		Use this handle to access the device.
*
*		index	The index of the device to access. Ignore if < 0.
*				This is for display purposes only.
*
*		verbose	Work verbosely?
*
*		get		The results are reported here. This may be NULL.
*
*	Returned:
*
*		>= 0	The number of errors encounterred.
*
******************************************************************************/

int dsi6c500k_auto_cal_sts(int fd, int index, int verbose, s32* get)
{
	char		buf[128];
	int			errs;
	const char*	ptr;
	int			ret;
	s32			set;

	if (verbose)
		gsc_label_index("Auto-Cal Status", index);

	ret		= dsi6c500k_ioctl(fd, DSI6C500K_IOCTL_AUTO_CAL_STS, &set);
	errs	= ret ? 1 : 0;

	switch (set)
	{
		default:

			errs++;
			ptr	= buf;
			sprintf(buf, "Unrecognized option: 0x%lX", (long) set);
			break;

		case DSI6C500K_AUTO_CAL_STS_ACTIVE:

			ptr	= "Active";
			break;

		case DSI6C500K_AUTO_CAL_STS_FAIL:

			ptr	= "Fail";
			break;

		case DSI6C500K_AUTO_CAL_STS_PASS:

			ptr	= "PASS";
			break;
	}

	if (verbose)
		printf("%s  (%s)\n", errs ? "FAIL <---" : "PASS", ptr);

	if (get)
		get[0]	= set;

	return(errs);
}


